@@ -308,7 +308,7 @@ impl SyntaxError {
             SyntaxError::ReservedWordInImport => "cannot import as reserved word".into(),
             SyntaxError::AssignProperty => "assignment property is invalid syntax".into(),
             SyntaxError::Expected(token, ref got) => {
-                format!("Expected {:?}, got {}", token, got).into()
+                format!("Expected '{:?}', got '{}'", token, got).into()
             }
             SyntaxError::ExpectedSemiForExprStmt { .. } => "Expected ';', '}' or <eof>".into(),
 
